summaryrefslogtreecommitdiff
path: root/src/include/taler_signatures.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_signatures.h')
-rw-r--r--src/include/taler_signatures.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/taler_signatures.h b/src/include/taler_signatures.h
index fa78c7a05..626526777 100644
--- a/src/include/taler_signatures.h
+++ b/src/include/taler_signatures.h
@@ -1061,9 +1061,9 @@ struct PaymentResponsePS
struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
/**
* Hash of the contract associated with this confirmation
*/
- struct GNUNET_HashCode h_contract;
+ struct GNUNET_HashCode h_proposal_data;
};
@@ -1061,9 +1061,9 @@ struct PaymentResponsePS
struct GNUNET_CRYPTO_EccSignaturePurpose purpose;
/**
- * Hash of the contract associated with this confirmation
+ * Hash of the proposal data associated with this confirmation
*/